# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-image
#
# Copyright (c) 2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    b532f935ee8eac08b6f94606e105c7e7c5745477
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-image
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Image
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.0.10
Release:        2%{?dist}
Summary:        PHP library containing PDF Image methods

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.1.2
BuildRequires:  php(language) >= 8.0
BuildRequires:  php-gd
BuildRequires:  php-zlib
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
BuildRequires: (php-composer(%{c_vendor}/tc-lib-file)        >= 2.0     with php-composer(%{c_vendor}/tc-lib-file)        < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-color)       >= 2.0     with php-composer(%{c_vendor}/tc-lib-color)       < 3)
BuildRequires: (php-composer(%{c_vendor}/tc-lib-pdf-encrypt) >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt) < 3)
%else
BuildRequires:  php-%{c_vendor}-tc-lib-file                  <  3
BuildRequires:  php-%{c_vendor}-tc-lib-file                  >= 2.0
BuildRequires:  php-%{c_vendor}-tc-lib-color                 <  3
BuildRequires:  php-%{c_vendor}-tc-lib-color                 >= 2.0
BuildRequires:  php-%{c_vendor}-tc-lib-pdf-encrypt           <  3
BuildRequires:  php-%{c_vendor}-tc-lib-pdf-encrypt           >= 2.1
%endif
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#    "php": ">=8.0",
#    "ext-gd": "*",
#    "ext-zlib": "*",
#    "tecnickcom/tc-lib-file": "^2.0",
#    "tecnickcom/tc-lib-color": "^2.0",
#    "tecnickcom/tc-lib-pdf-encrypt": "^2.0"
Requires:       php(language) >= 8.0
Requires:       php-gd
Requires:       php-zlib
%if 0%{?fedora} >= 27 || 0%{?rhel} >= 8
Requires:      (php-composer(%{c_vendor}/tc-lib-file)        >= 2.0     with php-composer(%{c_vendor}/tc-lib-file)        < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-color)       >= 2.0     with php-composer(%{c_vendor}/tc-lib-color)       < 3)
Requires:      (php-composer(%{c_vendor}/tc-lib-pdf-encrypt) >= 2.1     with php-composer(%{c_vendor}/tc-lib-pdf-encrypt) < 3)
%else
Requires:       php-%{c_vendor}-tc-lib-file                  <  3
Requires:       php-%{c_vendor}-tc-lib-file                  >= 2.0
Requires:       php-%{c_vendor}-tc-lib-color                 <  3
Requires:       php-%{c_vendor}-tc-lib-color                 >= 2.0
Requires:       php-%{c_vendor}-tc-lib-pdf-encrypt           <  3
Requires:       php-%{c_vendor}-tc-lib-pdf-encrypt           >= 2.1
%endif
# From phpcompatinfo report for version 2.0.8
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library containing PDF Image methods.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Com/Tecnick/File/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Color/autoload.php',
    '%{_datadir}/php/Com/Tecnick/Pdf/Encrypt/autoload.php',
]);
EOF


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php php81 php82 php83; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc *.md
%doc test/images
%{php_project}


%changelog
* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-2
- add images in doc as used by tc-lib-pdf examples
- fix dependency on tc-lib-pdf-encrypt 2.1

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-1
- update to 2.0.10
- raise dependency on tc-lib-pdf-encrypt 2.1

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.8-1
- initial package, version 2.0.8

